==> pypl-bt-1.8.0.0.zip: braintree-spartacus-libs/projects/braintree-spartacus/core/src/braintree-checkout/services/errorHandling/braintree-error-handler.service.ts <==
import { HttpRequest, HttpErrorResponse } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import {
  BadRequestHandler,
  GlobalMessageService,
  GlobalMessageType,
  HttpErrorHandler,
  HttpResponseStatus,
  Priority
} from '@spartacus/core';

@Injectable({
  providedIn: 'root',
})
export class BraintreeErrorHandlerService extends BadRequestHandler {
  responseStatus = HttpResponseStatus.BAD_REQUEST;

  protected countryError = 'No country with the code';
  protected regionError = 'No region with the code';

  constructor(
    protected globalMessageService: GlobalMessageService,
    protected router: Router
    ){
    super(globalMessageService);
  }

  handleError(
    request: HttpRequest<any>,
    errorResponse: HttpErrorResponse
  ): void {
    super.handleError(request, errorResponse);
    if (errorResponse.error?.errors?.length > 0) {
      errorResponse.error?.errors.forEach((error) => {
        if (error.type === 'PaymentAuthorizationError') {
          this.globalMessageService.add(
            { key: 'error.authorization.failed' },
            GlobalMessageType.MSG_TYPE_ERROR
          );
        }else if (error.type === 'ConversionError' && this.checkErrorMessage(error.message)){
          this.globalMessageService.add(
            { key: 'error.address.provide' },
            GlobalMessageType.MSG_TYPE_WARNING
          );
          this.router.navigate(['/checkout/shipping-address']);
        } else if (error.type === 'BraintreeDeletePaymentDetailsWithNotCapturedOrderError') {
          this.globalMessageService.add(
              { key: 'error.braintree_delete_payment_details_with_not_captured_order' },
              GlobalMessageType.MSG_TYPE_ERROR
          );
        }
      });
    }
  }

  checkErrorMessage(message: string): boolean {
    return message.includes(this.regionError) || message.includes(this.countryError);
  }

  getPriority(): Priority {
    return Priority.NORMAL;
  }
}

==> pypl-bt_1.10.0.0.zip: braintree-spartacus-libs/projects/braintree-spartacus/core/src/braintree-checkout/services/errorHandling/braintree-error-handler.service.ts <==
import { HttpRequest, HttpErrorResponse } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import {
  BadRequestHandler,
  GlobalMessageService,
  GlobalMessageType,
  HttpErrorHandler,
  HttpResponseStatus,
  Priority
} from '@spartacus/core';

@Injectable({
  providedIn: 'root',
})
export class BraintreeErrorHandlerService extends BadRequestHandler {
  responseStatus = HttpResponseStatus.BAD_REQUEST;

  protected countryError = 'No country with the code';
  protected regionError = 'No region with the code';

  constructor(
    protected globalMessageService: GlobalMessageService,
    protected router: Router
    ){
    super(globalMessageService);
  }

  handleError(
    request: HttpRequest<any>,
    errorResponse: HttpErrorResponse
  ): void {
    super.handleError(request, errorResponse);
    if (errorResponse.error?.errors?.length > 0) {
      errorResponse.error?.errors.forEach((error) => {
        if (error.type === 'BrainTreeUnverifiedAccountPayPalError') {
          this.globalMessageService.add(
              { key: 'error.unverified_account' },
              GlobalMessageType.MSG_TYPE_ERROR
          );
          this.router.navigate(['login']);
        }
        if (error.type === 'DuplicateUidError') {
          this.globalMessageService.remove(GlobalMessageType.MSG_TYPE_ERROR);
          this.globalMessageService.add({ key: 'error.customerAlreadyExist'},
              GlobalMessageType.MSG_TYPE_ERROR);
          this.router.navigate(['login']);
        }
        if (error.type === 'PaymentAuthorizationError') {
          this.router.navigate(['/checkout/payment-details']);
          this.globalMessageService.add(
            { key: 'error.authorization.failed' },
            GlobalMessageType.MSG_TYPE_ERROR
          );
        } else if (error.type === 'ConversionError' && this.checkErrorMessage(error.message)){
          this.globalMessageService.add(
            { key: 'error.address.provide' },
            GlobalMessageType.MSG_TYPE_WARNING
          );
          this.router.navigate(['/checkout/shipping-address']);
        } else if (error.type === 'BraintreeDeletePaymentDetailsWithNotCapturedOrderError') {
          this.globalMessageService.add(
              { key: 'error.braintree_delete_payment_details_with_not_captured_order' },
              GlobalMessageType.MSG_TYPE_ERROR
          );
        } else if (error.type === 'BrainTreeCardVerifyError') {
          this.globalMessageService.add(
              { key: 'error.failedVerificationErrorMessage' },
              GlobalMessageType.MSG_TYPE_ERROR
          );
        } else if (error.type === 'BrainTreeCVVVerificationError') {
            this.globalMessageService.add(
                { key: 'error.failedCVVVerificationErrorMessage' },
                GlobalMessageType.MSG_TYPE_ERROR
            );
          }
      });
    }
  }

  checkErrorMessage(message: string): boolean {
    return message.includes(this.regionError) || message.includes(this.countryError);
  }

  getPriority(): Priority {
    return Priority.NORMAL;
  }
}
